#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.26
%define baseversionminus1 1.25

Name:           kubernetes%{baseversion}
Version:        1.26.15
Release:        150400.9.16.1
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
# Patch to advance autoscaling v2 as the preferred API version, to fix bsc#1219964, CVE-2024-0793
Patch6:         autoscaling-advance-v2-as-the-preferred-API-version.patch
# PATCH-FIX-UPSTREAM - make package build reproducible
Patch7:         https://github.com/kubernetes/kubernetes/pull/122680.patch
# Patch to fix CVE-2023-45288, bump x/net to v0.23.0
Patch8:         bump-x-net-to-v0_23_0.patch
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go >= 1.22.5
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.22
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.


# packages to build containerized control plane

%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Recommends:     kubernetes-kubelet-common = %{version}
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       cri-tools
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)
Recommends:     kubernetes%{baseversion}-kubelet

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes-client-common >= %{version}
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Obsoletes:      kubernetes%{baseversionminus1}-client-common
Recommends:     bash-completion

%description client-common
Kubernetes client tools common files

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
BuildRequires:  bash-completion
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion

%description client-bash-completion
Bash command line completion support for %{name}-client

%package client-fish-completion
Summary:        Fish Completion for %{name}-client
Group:          System/Shells
BuildRequires:  fish
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and fish)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-fish-completion
Provides:       kubernetes-client-fish-completion = %{version}
Conflicts:      kubernetes-client-fish-completion

%description client-fish-completion
Fish command line completion support for %{name}-client.

%prep
%setup -q -n kubernetes-%{version}
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p0
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
#%ifarch ppc64le
#export GOLDFLAGS='-linkmode=external'
#%endif

#TEST
export FORCE_HOST_GO=y
 
%ifarch s390x
# `-buildmode=pie` with "internal linking" is not yet supported on linux/s390x platform
# https://github.com/golang/go/blob/a63907808d14679c723e566cb83acc76fc8cafc2/src/internal/platform/supported.go#L223-L232
# https://github.com/golang/go/issues/64875#issuecomment-1870734528
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm"
%else
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"
%endif

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# install the fish completion
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/kubectl%{baseversion} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/kubectl.fish

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
# Check if /etc/sysconfig/kubelet exists
if [ -e "/etc/sysconfig/kubelet" ]; then
  # Extract the value from the fillup file
  UPDATED_KUBELET_VER=$(grep '^KUBELET_VER=' %{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion} | cut -d '=' -f2)
  # Update the value in the sysconfig file
  sed -i "s/^KUBELET_VER=.*/KUBELET_VER=$UPDATED_KUBELET_VER/" /etc/sysconfig/kubelet
fi
%service_add_post kubelet.service
if [ $1 -eq 1 ]; then
    # Check if modprobe command is available
    [ ! -x /sbin/modprobe ] || { /sbin/modprobe br_netfilter && /sbin/modprobe overlay; } || true
fi
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%post kubeadm
# Check if sysctl command is available
if [ -x /usr/sbin/sysctl ]; then
    # Run sysctl --system after the package installation
    /usr/sbin/sysctl -p %{_sysctldir}/90-kubeadm.conf || true
fi

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%files client-fish-completion
%{_datadir}/fish/vendor_completions.d/kubectl.fish

%changelog
* Tue Sep  3 2024 priyanka.saggu@suse.com
- Security fix for bsc#1229869
  * New Patch: bump-x-net-to-v0_23_0.patch
  - golang.org/x/net is bumped to v0.23.0 to address CVE-2023-45288
* Thu Aug 29 2024 priyanka.saggu@suse.com
- Follow up changes after go version bump to 1.22:
  - For ppc64le platform: disabled `export GOLDFLAGS='-linkmode=external'`.
  * to fix the build failure error:
    `-linkmode=external requires external (cgo) linking, but cgo is not enabled`
  - For linux/s390x platform: disabled building kubernetes binaries with `-buildmode=pie`
  * `-buildmode=pie` with "internal linking" is not yet supported on linux/s390x platform
  * ref: https://github.com/golang/go/blob/a63907808d14679c723e566cb83acc76fc8cafc2/src/internal/platform/supported.go#L223-L232
  * ref: https://github.com/golang/go/issues/64875#issuecomment-1870734528
* Thu Aug 29 2024 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements (per requested in bsc#1229858)
  * `BuildRequires:  go >= 1.22.5`
  * `BuildRequires:  golang(API) = 1.22`
* Tue Jul 30 2024 bwiedemann@suse.com
- Add upstream 122680.patch for reproducible builds (boo#1062303)
* Mon Apr  8 2024 priyanka.saggu@suse.com
- update .spec file to set FORCE_HOST_GO env variable,
  to force k8s build scripts use the local GOTOOLCHAIN version from the build pipeline
  (i.e. GOTOOLCHAIN='auto')
  * ref: https://github.com/kubernetes/kubernetes/blob/9791f0d1f39f3f1e0796add7833c1059325d5098/hack/lib/golang.sh#L507
* Mon Apr  8 2024 priyanka.saggu@suse.com
- Update to version 1.26.15:
  * [CVE-2024-24786] Bump github.com/golang/protobuf v1.5.4, google.golang.org/protobuf v1.33.0, bsc#1229867
  * [go] Bump images, dependencies and versions to go 1.21.8 / distroless-iptables to v0.4.6
* Mon Feb 26 2024 priyanka.saggu@suse.com
- add new patch to advance autoscaling v2 as the preferred API version, to fix bsc#1219964, CVE-2024-0793
  * autoscaling-advance-v2-as-the-preferred-API-version.patch
* Mon Feb 26 2024 priyanka.saggu@suse.com
- Update to version 1.26.14:
  * [go] Bump images, dependencies and versions to go 1.21.7 / distroless-iptables to v0.4.5
  * Add processStartTime in metrics/slis
  * If a pvc has an empty storageclass name, don't try to assign a default StorageClass to it.
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  golang(API) = 1.21`
* Thu Feb 22 2024 dimstar@opensuse.org
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Jan 24 2024 priyanka.saggu@suse.com
- Update .spec file to remove go version build requirements:
  * above build requirement causing build failures with following error:
  - `go: download go1.20.13 for linux/amd64: toolchain not available`
  - ref: https://go.dev/doc/toolchain
- Update to version 1.26.13:
  * [go] Bump images, dependencies and versions to go 1.20.13 and distroless iptables to 0.2.9
  * Handle edge cases in seat demand stats
  * fix: 119921
  * Use a separate function for checking if device was reconstructed
  * Add tests for checking of uncertain device paths
  * Fix device uncertain errors on reboot
  * fix(scheduler): fix incorrect loop logic in MultiPoint to avoid a plugin being loaded multiple times
  * etcd: Update to version 3.5.10
* Wed Jan 24 2024 priyanka.saggu@suse.com
- Update to version 1.26.12:
  * run update-vendor script
  * [go] Bump images, dependencies and versions to go 1.20.12
  * pass GOTOOLCHAIN to build containers
  * handle GOTOOLCHAIN in kube::golang::verify_go_version
  * fix: requeue pods rejected by Extenders properly
  * Bump distroless-iptables to v0.2.8 that uses go1.20.11
  * fix: smb file share unavailable issue when it's deleted
  * run hack scripts to update cyphar/filepath-securejoin to v0.2.4 correctly
  * update filepath-securejoin dependency to 0.2.4 to fix security vulnerability
* Fri Nov 24 2023 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.11`
- Update to version 1.26.11:
  * Use golang library instead of mklink
  * [go] Bump images, dependencies and versions to go 1.20.11
  * Fixing attempt to deploy past allocatable memory limits test on Windows
  * bump golang.org/grpc to v1.56.3
  * Add more test cases ensuring nextScheduleTimeDuration is never < 0
  * Modify mostRecentScheduleTime to return more detailed information about missed schedules
  * Re-use common parts between getNextScheduleTime and nextScheduledTimeDuration
  * Cleanups in controller utils
  * Fixing gmsa-webhook install steps for Windows GMSA full tests
  * Service controller: improve node lifecycle updates
  * KCCM: fix GCP ILB by reintroducing readiness predicate for eTP:Local
  * Use Patch instead of SSA for Pod Disruption condition
  * Retry operations if CSI Driver Isn't Found by Treating this Error as Transient
* Thu Oct 26 2023 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.10`
- Update to version 1.26.10:
  * Release commit for Kubernetes v1.26.10
  * Register UnauthenticatedHTTP2DOSMitigation into kube components  (CVE-2023-44487, CVE-2023-39325), bsc#1229869
  * Skip TestUnauthenticatedHTTP2ClientConnectionClose http1 tests  (CVE-2023-44487, CVE-2023-39325), bsc#1229869
  * Disable UnauthenticatedHTTP2DOSMitigation by default  (CVE-2023-44487, CVE-2023-39325), bsc#1229869
  * Prevent rapid reset http2 DOS on API server  (CVE-2023-44487, CVE-2023-39325), bsc#1229869
  * Fix concurrent write when filling PVC labels
  * Modify test PVC to detect concurrent map write bug
  * [go] Bump images, dependencies and versions to go 1.20.10
  * .: bump golang.org/x/net to v0.17.0
  * Add nil checks for hpa object target type values
  * Mark a volume as uncertain-attached after detach error
  * [go] Bump images, versions and deps to use Go 1.20.9
  * bump etcd cluster image to 3.5.9
  * cronjob controller: ensure already existing jobs are added to Active list of cronjobs
  * change rolling update logic to exclude sunsetting nodes
  * vsphere: adapt to govmomi bump
  * .: bump govmomi to v0.30.6
  * Increase range of job_sync_duration_seconds
  * sync Service API status rest storage
  * scheduler: start scheduling attempt with clean UnschedulablePlugins
  * updating dependencies.yaml for etcd v3.5.9 version
  * use upstream etcd github path instead of redirecting one
  * update etcd version in install.sh to 3.5.9
  * move check for noop managed field timestamp updates
* Wed Sep 20 2023 priyanka.saggu@suse.com
- fixes for bsc#1214406
- update `Wants` directive in [Unit] section of `kubelet.service`:
  * add: `containerd.service`
  * remove: `docker.service`
- updating container runtime prerequisites:
  (Refer: k8s.io/docs/setup/production-environment/container-runtimes/#install-and-configure-prerequisites)
  * update `90-kubeadm.conf` to add below iptables rules:
  - net.bridge.bridge-nf-call-iptables = 1
  - net.bridge.bridge-nf-call-ip6tables = 1
  * update `kubeadm.conf` to add `overlay` kernel module
  * update .spec file to:
  - add post-installation scriptlet for `kubeadm` package to enable iptables rules defined in `90-kubeadm.conf` using sysctl
  - add conditional checks to load kernel modules (br_netfilter, overlay) in `kubelet-common` package post-installation scriptlet
  - update `kubelet-common` post scriptlet to correctly update `KUBELET_VER` var in `/etc/sysconfig/kubelet` file based on fillup template
- add below to `kubelet` subpackage to recommend installing correct version of package providing `kubernetes-kubelet-common` :
  * `Recommends: kubernetes-kubelet-common = %%{version}`
- add below to `kubeadm` subpackage to recommend installing correct version of `kubelet` and `kubelet-common` packages:
  * `Recommends: kubernetes%%{baseversion}-kubelet`
* Wed Sep 20 2023 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.8`
- Update to version 1.26.9:
  * Release commit for Kubernetes v1.26.9
  * [go] Bump images, versions and deps to use Go 1.20.8
  * Automated cherry pick of #119776: Fix a job quota related deadlock (#120321)
  * TopologyAwareHints: Take lock in HasPopulatedHints
  * Mark Job onPodConditions as optional in pod failure policy
  * Update CHANGELOG/CHANGELOG-1.26.md for v1.26.8
  * Incorporating feedback on 119341
  * check for overflow
  * Fix CEL cost handling of zero length replacement strings
  * generate ReportingInstance and ReportingController in Event
  * Pass Pinned field to kubecontainer.Image
  * update otelhttp to v0.35.1
  * prep for go1.21: use -e in go list
  * Skip apiserver_admission_webhook_request_total during context-canceled
  * Ignore context canceled from validate and mutate webhook failopen metric
  * kubeadm: fix nil pointer when etcd member is already removed
  * update to golangci-lint v1.54.1 + go-ruleguard v0.4.0
  * fix: when PreFilter returns UnschedulableAndUnresolvable, copy the state in all nodes in statusmap
  * Issue 4230: remove readiness check for cache exclusion
  * run dummy command return status 0
  * unit test not requiring priviledge
  * Revert "Revert #114605: its unit test requires root permission"
  * node: devicemgr: topomgr: add logs
  * e2e: node: add test to check device-requiring pods are cleaned up
  * e2e: node: devices: improve the node reboot test
  * e2e: node: devicemanager: update tests
  * kubelet: devices: skip allocation for running pods
  * Add test coverage of result size of string operations
  * Bump cel-go to v0.12.7
* Tue Sep 12 2023 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.7`
- Update to version 1.26.8:
  * Release commit for Kubernetes v1.26.8
  * Use environment varaibles for parameters in Powershell
  * Use env varaibles for passing path
  * Avoid returning nil responseKind in v1beta1 aggregated discovery
  * [release-1.26] releng/go: Bump images, versions and deps to use Go 1.20.7 and update protoc
  * e2e_node: move getSampleDevicePluginPod to device_plugin_test.go
  * fix 'pod' in kubelet prober metrics
  * priority & fairness: support dynamically configuring work estimator max seats
  * events: fix EventSeries starting count discrepancy
  * tools/events: fix data race when emitting series
  * tools/events: retry on AlreadyExist for Series
  * kubeadm: backdate generated CAs by 5 minutes
  * client-go: allow to set NotBefore in NewSelfSignedCACert()
  * Fix a data race in TopologyCache
  * Fix TopologyAwareHint not working when zone label is added after Node creation
* Tue Aug  1 2023 eich@suse.com
- Restore the correct content of the  kublet wrapper script (boo#1213829).
* Wed Jul 26 2023 priyanka.saggu@suse.com
- Update: `BuildRequires:  go >= 1.20.6`
- Update: `BuildRequires:  golang(API) = 1.20`
- Update to version 1.26.7:
  * [release-1.26] releng/go: Bump images, versions and deps to use Go 1.20.6
  * Fix the converts an empty string to nil.
  * Add unit tests for parallel StatefulSet create & delete
  * Parallel StatefulSet pod create & delete
  * Refactor StatefulSet controller update logic
  * Only declare job as finished after removing all finalizers
  * Cherry pick of #118716 upstream release 1.26 (#118912)
  * Hide numberOfMissedSchedules as an algorithm internal number
  * Update schedule logic to properly calculate missed schedules
  * kubeadm: set priority for "system-node-critical" Pods
  * Automated cherry pick of #118805: test comment should match the code in podgc (#118914)
  * call ./hack/update-vendor.sh
  * kubeadm: remove function pointer comparison in phase test
  * Make etcd component status consistent with health probes
  * Fix deadlock in ready test
  * fix the existing problem (0 SerialNumber in all certificate) as part of this PR in a separate commit
  * update serial number to a valid non-zero number in ca certificate
  * deps: Bump to cAdvisor v0.46.1
  * AWS: fix code for picking region from zone
  * Fix the git-repo test error caused by the correct use of loop variables
  * dra scheduler plugin test: fix loopvar bug and "reserve" expected data
  * don't process unsupported loadbalancers with mixed protocols
  * make MixedProtocolNotSupported public
  * Add node check to vSphere cloud provider
  * Set permissions on volume before publishing update
  * Adding additional validations to queried endpoint list iteration.
* Wed Jun 21 2023 priyanka.saggu@suse.com
- Update: `BuildRequires:  go >= 1.19.10`
- Update to version 1.26.6:
  * Release commit for Kubernetes v1.26.6
  * update-vendor: update vendored go.sums
  * [release-1.26] releng/go: Update images, dependencies and version to Go 1.19.10
  * kube-proxy avoid race condition using LocalModeNodeCIDR
  * Add ephemeralcontainer to imagepolicy securityaccount admission plugin
  * Add DisruptionTarget condition when preempting for critical pod
  * update webhook test to go 1.21
  * Test APIService safe handling at startup
  * Fix waiting for CRD sync at server start
  * kubeadm: fix a bug where the static pod changes detection logic is inconsistent with kubelet
  * kubeadm: Make etcd member removal idempotent
  * kubeadm: Add etcd client unit tests
  * kubeadm: Use internal etcd client through an interface
  * run update-vendor.sh
  * vclib: Modify x509.UnknownAuthorityError unwrap check
  * vsphere: Adapt to govmomi version bumps
  * *: Bump version of vmware/govmomi
* Mon Jun 12 2023 priyanka.saggu@suse.com
- Update BuildRequires:  `go >= 1.19.9`
- Update to version 1.26.5:
  * Release commit for Kubernetes v1.26.5
  * benchmark test to evaluate the overhead of podMatchesScopeFunc
  * Fix incorrect calculation for ResourceQuota with PriorityClass as its scope
  * Update podFailurePolicy comments from alpha-level to beta
  * releng/go: Update images, dependencies and version to Go 1.19.9
  * Kube-proxy/ipvs: accept access to healthCheckNodePort on LbIP
  * node: device-plugin: e2e: Additional test cases
  * node: device-plugin: add node reboot test scenario
  * node: device-plugin: e2e: Capture pod admission failure
  * node: device-mgr: e2e: adapt to sample device plugin refactoring
  * node: device-mgr: e2e: Update the e2e test to reproduce issue:109595
  * node: device-mgr: e2e: Implement End to end test
  * node: device-mgr: Handle recovery by checking if healthy devices exist
  * node: device-plugin: e2e: Add test case for kubelet restart
  * node: device-plugin: e2e: Provide sleep intervals via constants
  * node: device-plugin: e2e: Update test description to make it explicit
  * node: device-plugin: e2e: Isolate test to pod restart scenario
  * node: device-plugin: e2e: Annotate device check with error message
  * node: device-plugins: e2e: s/devLen/expectedSampleDevsAmount
  * node: device-plugins: e2e: Refactor parse log to return string and error
  * test: Fix path to e2e node sample device plugin
  * node: device-mgr: sample device plugin: manifest to avoid registration
  * node: device-mgr: sample device plugin: control registration process
  * e2e: node: unify sample device plugin utilities
  * Bump runc go module v1.1.4 -> v1.1.6
  * Use absolute path instead requestURI in openapiv3 discovery
  * Correct the changelog for GlusterFS removal in 1.26.
  * Refactors discovery content-type and helper functions
  * Fix directory mismatch for `volume.SetVolumeOwnership()`
  * Investigate and fix the handling of Succeeded pods in DaemonSet
  * KCCM: add providerID predicate to service controller
  * add log includes pod preemption details
  * fix: the volume is not detached after the pod and PVC objects are deleted
  * use case-insensitive header keys for http probes
  * kube-aggregator: correctly use client-go TLS cache with custom dialer
  * Do not look at VPC-related resources outside the cluster's network
  * Bump konnectivity-client to 0.0.37
  * kubelet: Do not mutate pods in the pod manager
  * Fix azure disk e2e after migration
  * Return error for localhost seccomp type with no localhost profile defined
  * Bump the timeout for volume expansion
  * Wait for pod to be running before expanding
* Thu Apr 13 2023 priyanka.saggu@suse.com
- Update to version 1.26.4:
  * Release commit for Kubernetes v1.26.4
  * releng/go: Update images, dependencies and version to Go 1.19.8
  * Drop development dependencies from test targets
  * Clear front proxy headers after authentication is complete
  * Make prerelease tag optional in CI versions
  * Annotate CI version regexes
  * Drop unused regex grouping
  * Delete unused version regex function
  * kubelet: Fix fs quota monitoring on volumes
  * fsquota: only generate pod uuid is nil
  * Preserve UID/ResourceVersion in the BindingREST endpoint
  * Add integration test for DefaultBinder
  * API-initiated eviction: handle deleteOptions correctly
  * Change where transformers are called.
  * Aggregated discovery resilient to nil GVK
  * wait again on pending state
  * cacher allow context cancellation if not ready
  * Unlock CSIMigrationvSphere feature gate until there is a supported vSphere CSI driver available
  * Route controller should update routes with NodeIP changed When a node reboots or kubelet restarts, it is possible that its IP is changed. In this case, node route should be updated with the correct IP. In this PR, it checks if the IP in an existing route is the same as the actual one. If not, it marks it as "update" so the old route will be deleted and a new one will be created. There's a new field EnableNodeAddresses, which is a feature gate for specific cloud providers to enable after they update their cloud provider code for CreateRoute().
  * client-go/cache: update Replace comment to be more clear
  * client-go/cache: rewrite Replace to check queue first
  * client-go/cache: merge ReplaceMakesDeletionsForObjectsInQueue tests
  * client-go/cache: fix missing delete event on replace without knownObjects
  * client-go/cache: fix missing delete event on replace
  * CHANGELOG-1.26: move OpenStack in-tree provider removal to urgent notes
* Mon Mar 27 2023 rombert@apache.org
- Stronger conflicts for completion packages
* Mon Mar 27 2023 rombert@apache.org
- Split individual completions into separate packages
* Wed Mar 22 2023 priyanka.saggu@suse.com
- Add "BuildRequires: go>=1.19.7" in spec file
* Tue Mar 21 2023 priyanka.saggu@suse.com
- Update to version 1.26.3:
  * Release commit for Kubernetes v1.26.3
  * Avoid metric lookup in Parallelizer.Util on every work piece
  * One lock among PodNominator and SchedulingQueue
  * Removes old discovery hack ignoring 403 and 404
  * Plumb stale GroupVersions through aggregated discovery
  * releng/go: Update images, dependencies and version to Go 1.19.7
  * Tolerate empty discovery response in memcache client
  * Fix for windows kube-proxy: 'externalTrafficPolicy: Local' results in no clusterIP entry in windows node.
  * Deflake tests in staging/src/k8s.io/kube-aggregator/pkg/apiserver
  * Fix a data race in TestDirty
  * ut: fix TestLegacyFallbackNoCache versions order
  * Fix legacy fallback stale for aggregated discovery
  * Re-enable label selector
  * Add integration test for diff --prune --selector
  * Use label selector for filtering out resources when pruning. Matches same behavior as for kubectl apply
  * svc: Support pods with same address
  * api: generated files
  * api: drop Resources.Claims from PVC and PVC template
  * scheduler/framework/plugins/volumebinding: fix inaccurate log for when a volume is bound to a claim
  * Fix validation.go to validate without StatefulSetStartOrdinal feature gate check. Adds test case to validate regression fix of validation failing when spec.ordinals set and feature gate disabled
  * Remove global framework variable
  * fix race in aggregated discovery handler
  * Remove check for CSI driver running on node for CSI migration attach operations
  * Disable multiple pv mount tests for vsphere intree driver
  * Simplify construction of /metrics request
  * Fix for issue with Loadbalancer policy creation for IPV6 endpoints in Dualstack mode.
  * Bump konnectivity-client to v0.0.36
  * make GetSubnetPrefix IP family agnostic
  * Invoke gimme from kube::golang::verify_go_version
  * Defer builds to test-cmd and test-integration targets
  * Set node_stage whenever available
  * Carefully compute request path for metrics
* Thu Mar  9 2023 priyanka.saggu@suse.com
- Update to version 1.26.2:
  * Release commit for Kubernetes v1.26.2
  * releng: Update images, dependencies and version to Go 1.19.6
  * Update golang.org/x/net to v0.7.0
  * Pin golang.org/x/net to v0.4.0 in 1.26
  * Enforce nodeName cannot be set along with non empty schedulingGates
  * kubelet/client: collapse transport wiring onto standard approach
  * Ignore container events with nil PodSandboxStatus
  * apiserver: remove 34s from DELETECOLLECTION rest handler
  * update prev succeeded indexes for indexed jobs unconditionally
  * dynamic resource allocation: avoid apiserver complaint about list content
  * Avoid typechecking stdlib
  * Fix konnectivity-client metric registration.
  * Fix nil pointer error in nodevolumelimits csi logging
  * add scale test for probes
  * kubectl: use v2 for hpa
  * Fix panic on ClusterIP allocation for /28 subnets
  * use custom dialer for http probes
  * use custom dialer for tcp probes
  * add custom dialer optimized for probes
  * k8s.io/component-base/logs: match full help text in unit test
  * k8s.io/component-base/logs: relax flagset unit tests
  * k8s.io/component-base/logs: unit test for command line help output
  * k8s.io/component-base/logs: fix usage through Go flag package
  * fix bug with param controllers being removed if used by more than one policy
  * bump honnef.co/go/tools to support go1.20
  * PodGC should not add DisruptionTarget condition for pods which are in terminal phase
  * pkg/controller/job: re-honor exponential backoff
  * releng: Update images, dependencies and version to Go 1.19.5
  * Do not include scheduler name in the preemption event message
  * Explicitly call rand.Seed() method
  * Exports WarningPrinter field in DeleteOptions
  * Do not leak cross namespace pod metadata in preemption events
  * Adjust DisruptionTarget condition message to do not include preemptor pod metadata
  * egress_selector.go: register konnectivity-client metrics.
  * expose prometheus.Registerer so that we can hook into this from external sources
  * Bump konnectivity-client to v0.0.35
  * Cherry pick 114857 to release-1.26
  * Automated cherry pick of #114602: Removed the reverted changes from Changelogv1.26.md
  * Update daemonSet status even if syncDaemonSet fails
  * Licensing: skip modules with fewer subdirs than mods
  * Fix issues in volumesnapshot test for ephemeral storage
  * Fix clearing rate limiter in disruption controller
  * Add pod to dsw if termination is not completed during reconstruction #issues/113979
  * Add .go-version file containing build go version
  * Windows Kube-Proxy implementation for internal traffic policy.
  * Fix a regression that scheduler always go through all Filter plugins
  * Fix SPDY proxy authentication with special chars
  * fix double lock and excercise its codepath in tests
  * Creating Ingress IP loadbalancer alone when all the endpoints are terminating. KEP1669
  * Deflake a preemption test that may patch Node incorrectly
  * Introducing LoadbalancerPortMapping flags for VipExternalIP
* Thu Mar  9 2023 priyanka.saggu@suse.com
- initial package
